@@ -103,6 +103,11 @@ def control_monthly_screen(stdscr, user_events, screen, importer):
                     screen.day = day
                     screen.calendar_state = CalState.DAILY
 
+            # Change the view to daily:
+            if screen.key == "v":
+                screen.day = 1
+                screen.calendar_state = CalState.DAILY
+
             # Add single event:
             if screen.key == "a":
                 question = f'{MSG_EVENT_DATE} {screen.year}/{screen.month}/'
@@ -257,6 +262,10 @@ def control_daily_screen(stdscr, user_events, screen, importer):
                 if confirmed:
                     importer.import_events_from_calcurse()
 
+            # Change the view to monthly:
+            if screen.key == "v":
+                screen.calendar_state = CalState.MONTHLY
+
             # Other actions:
             if vim_style_exit(stdscr, screen):
                 confirmed = ask_confirmation(stdscr, MSG_EXIT, cf.ASK_CONFIRMATIONS)
@@ -294,7 +303,10 @@ def control_journal_screen(stdscr, user_tasks, screen, importer):
                 number = input_integer(stdscr, screen.y_max-2, 0, MSG_TM_ADD)
                 if user_tasks.is_valid_number(number):
                     task_id = user_tasks.items[number].item_id
+                    if cf.ONE_TIMER_AT_A_TIME:
+                        user_tasks.pause_all_other_timers(task_id)
                     user_tasks.add_timestamp_for_task(task_id)
+
             if screen.key == 'T':
                 number = input_integer(stdscr, screen.y_max-2, 0, MSG_TM_RESET)
                 if user_tasks.is_valid_number(number):
